﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using WinRTComponent;
using Windows.Foundation.Collections;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Navigation;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=234238

namespace CSTester
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class MainPage : Page
    {
		Component c = new Component();

        public MainPage()
        {
            this.InitializeComponent();
        }

        /// <summary>
        /// Invoked when this page is about to be displayed in a Frame.
        /// </summary>
        /// <param name="e">Event data that describes how this page was reached.  The Parameter
        /// property is typically used to configure the page.</param>
        protected override async void OnNavigatedTo(NavigationEventArgs e)
        {
			// simple types
			int x = c.Add(1,2);
			Single y = c.Sub(2, 1);

			// WinRT type conversions
			c.Navigate(new Uri("http://channel9.msdn.com/coding4fun/"));
			DateTimeOffset dto = c.GetTime();

			// Collections
			int[] numbers = new[] { 1, 2, 3, 4, 5, 6};
			List<int> listNumbers = new List<int>(numbers);
			float average = c.Average(listNumbers); // note that "float" == "System.Single" in .NET

			Dictionary<string, int> dict = new Dictionary<string,int>();
			dict["hi"] = 1;
			c.SetDictionary(dict);

			PropertySet ps = new PropertySet();
			ps["hi"] = 1;
			c.SetIPropertySet(ps);

			// no conversion from PropertySet to Dictionary
			//c.SetIMap(dict);

			// arrays
			Single averageArray = c.AverageArray(numbers);

			// these work, but they're not proper for cross-platform dev
			c.ArrayReadOnly(numbers, 10);
			c.ArrayWriteOnly(numbers, 10);
			c.ArrayOut(out numbers, 10);
			c.ArrayClone(numbers, 10);

			numbers = c.ArrayCloneReturn(numbers, 10);

			// overload (we can use them all here in managed code)
			c.Overload("string");
			c.Overload(1.0f);
			c.Overload(1);

			// events
			c.MyEvent += (sender, args) => Debug.WriteLine("event --> " + args.Field);
			c.RaiseEvent();

			// exceptions
	        try
	        {
				c.ThrowFileNotFoundException();
	        }
	        catch(Exception ex)
	        {
				Debug.WriteLine(ex.Message);
	        }

	        try
	        {
				c.ThrowNullReferenceException();
	        }
	        catch (Exception ex)
	        {
				Debug.WriteLine(ex.Message);
	        }

	        try
	        {
				c.ThrowCOMException();
	        }
	        catch(Exception ex)
	        {
				Debug.WriteLine(ex.Message);
	        }

	        try
	        {
				c.ThrowMyException();
	        }
	        catch(Exception ex)
	        {
				Debug.WriteLine(ex.Message);
	        }

			// async
			string done;
			await c.AsyncAction();
			done = await c.AsyncOperation();
			await c.AsyncActionCancellation();
			done = await c.AsyncOperationCancellation();
			await c.AsyncActionProgress();
			done = await c.AsyncOperationProgress();
        }
    }
}
